@@ -10,7 +10,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
+	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 )
 
 var machineDefaultConfig = &common.RunnerConfig{
@@ -315,7 +315,8 @@ func TestMachineCreationAndRemoval(t *testing.T) {
 	assert.NoError(t, <-errCh)
 	assert.Equal(t, machineStateUsed, d3.State)
 
-	p.remove(d.Name)
+	err := p.remove(d.Name)
+	assert.NoError(t, err)
 	assert.Equal(t, machineStateRemoving, d.State)
 }
 
@@ -435,11 +436,13 @@ func TestMachineLimitMax(t *testing.T) {
 
 	config.Limit = 8
 	d, err = p.Acquire(config)
+	assert.NoError(t, err)
 	p.Release(config, d)
 	assertIdleMachines(t, p, 8, "it should upscale to 8 nodes")
 
 	config.Limit = 2
 	d, err = p.Acquire(config)
+	assert.NoError(t, err)
 	p.Release(config, d)
 	assertIdleMachines(t, p, 2, "it should downscale to 2 nodes")
 }
